@@ -1,4 +1,5 @@
-# Copyright 2017 QuantRocket LLC - All Rights Reserved
+# -*- coding: utf-8 -*-
+# Copyright 2017-2022 QuantRocket LLC - All Rights Reserved
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,13 +15,20 @@
 
 import numpy as np
 import pandas as pd
-
-from quantrocket.blotter import read_pnl_csv
-from quantrocket.moonshot import read_moonshot_csv
-
-from .utils import *
-from .utils import trim_outliers as trim_outliers_func
 from .exceptions import InsufficientData, MoonchartError
+from .utils import (
+    get_zscores,
+    trim_outliers as trim_outliers_func,
+    get_sharpe,
+    get_rolling_sharpe,
+    get_cagr,
+    get_cum_returns,
+    get_drawdowns,
+    intraday_to_daily,
+)
+
+from quantrocket.moonshot import read_moonshot_csv
+from quantrocket.blotter import read_pnl_csv
 
 
 class DailyPerformance(object):
@@ -77,7 +85,6 @@ class DailyPerformance(object):
     def __init__(
         self,
         returns,
-        results=None,
         pnl=None,
         net_exposures=None,
         abs_exposures=None,
@@ -91,16 +98,16 @@ class DailyPerformance(object):
         compound=True,
         rolling_sharpe_window=200,
         trim_outliers=None,
-        weights=None,
     ):
 
         self.returns = returns
         if len(self.returns.index) < 2:
             raise InsufficientData(
                 "Moonchart needs at least 2 dates to analyze performance, "
-                "but returns DataFrame has length {0}".format(len(self.returns.index)))
+                "but returns DataFrame has length {0}".format(len(self.returns.index))
+            )
         self._trim_outliers = trim_outliers
-        if self._trim_outliers:
+        if trim_outliers:
             self.returns = trim_outliers_func(returns, z_score=trim_outliers)
         else:
             # warn the user if there are >10-sigma returns
@@ -110,11 +117,14 @@ class DailyPerformance(object):
                 max_zscore = max_zscore.max()
             if max_zscore > 20:
                 import warnings
-                warnings.warn("Found returns which are {0} standard deviations from the "
-                              "mean, consider removing them with the `trim_outliers` parameter".format(
-                                  round(max_zscore)))
+
+                warnings.warn(
+                    "Found returns which are {0} standard deviations from the "
+                    "mean, consider removing them with the `trim_outliers` parameter".format(
+                        round(max_zscore)
+                    )
+                )
         self.pnl = pnl
-        self.results = results
         self.net_exposures = net_exposures
         self.abs_exposures = abs_exposures
         self.total_holdings = total_holdings
@@ -125,9 +135,6 @@ class DailyPerformance(object):
         self.riskfree = riskfree
         self.compound = compound
         self.rolling_sharpe_window = rolling_sharpe_window
-        self.weights = weights
-        self.returns_longs = None if self.weights is None else self.returns[self.weights > 0]
-        self.returns_shorts = None if self.weights is None else self.returns[self.weights < 0]
         self._benchmark_prices = benchmark
         self._benchmark_returns = None
         self._benchmark_cum_returns = None
@@ -141,24 +148,19 @@ class DailyPerformance(object):
         self._drawdowns = None
         self._max_drawdown = None
         self._cum_pnl = None
-        self._average_holding_periods_pos = None
-        self._average_holding_periods_null = None
-        self._top_movers = None
-        self._bar_size = None
-        self._cagr_shorts = None
-        self._cagr_longs = None
-        self._cum_returns_shorts = None
-        self._cum_returns_longs = None
 
     @classmethod
-    def _from_moonshot_or_pnl(cls, results,
-                              start_date=None,
-                              end_date=None,
-                              trim_outliers=None,
-                              how_to_aggregate=None,
-                              riskfree=0,
-                              compound=True,
-                              rolling_sharpe_window=200):
+    def _from_moonshot_or_pnl(
+        cls,
+        results,
+        start_date=None,
+        end_date=None,
+        trim_outliers=None,
+        how_to_aggregate=None,
+        riskfree=0,
+        compound=True,
+        rolling_sharpe_window=200,
+    ):
         """
         Creates a DailyPerformance instance from a moonshot backtest results
         DataFrame or a PNL DataFrame.
@@ -177,9 +179,8 @@ class DailyPerformance(object):
             trim_outliers=trim_outliers,
             riskfree=riskfree,
             compound=compound,
-            rolling_sharpe_window=rolling_sharpe_window
+            rolling_sharpe_window=rolling_sharpe_window,
         )
-        kwargs["results"] = results
         kwargs["returns"] = results.loc["Return"]
 
         if "Pnl" in fields:
@@ -195,25 +196,28 @@ class DailyPerformance(object):
         if "Commission" in fields:
             kwargs["commissions"] = results.loc["Commission"]
         if "CommissionAmount" in fields:
-            kwargs["commission_amounts"] = results.loc["CommissionAmount"].astype(np.float64)
+            kwargs["commission_amounts"] = results.loc["CommissionAmount"].astype(
+                np.float64
+            )
         if "Slippage" in fields:
             kwargs["slippages"] = results.loc["Slippage"]
         if "Benchmark" in fields:
             kwargs["benchmark"] = results.loc["Benchmark"]
-        if "Weight" in fields:
-            kwargs["weights"] = results.loc["Weight"]
 
         return cls(**kwargs)
 
     @classmethod
-    def from_moonshot_csv(cls, filepath_or_buffer,
-                          start_date=None,
-                          end_date=None,
-                          trim_outliers=None,
-                          how_to_aggregate=None,
-                          riskfree=0,
-                          compound=True,
-                          rolling_sharpe_window=200):
+    def from_moonshot_csv(
+        cls,
+        filepath_or_buffer,
+        start_date=None,
+        end_date=None,
+        trim_outliers=None,
+        how_to_aggregate=None,
+        riskfree=0,
+        compound=True,
+        rolling_sharpe_window=200,
+    ):
         """
         Creates a DailyPerformance instance from a Moonshot backtest results CSV.
 
@@ -267,7 +271,9 @@ class DailyPerformance(object):
                 raise
             results = pd.read_csv(filepath_or_buffer)
             if "StrategyOrDate" in results.columns:
-                raise MoonchartError("this is a parameter scan CSV, please use ParamscanTearsheet.from_moonshot_csv")
+                raise MoonchartError(
+                    "this looks like a parameter scan CSV, please use ParamscanTearsheet.from_csv"
+                )
             else:
                 raise
 
@@ -279,17 +285,21 @@ class DailyPerformance(object):
             how_to_aggregate=how_to_aggregate,
             riskfree=riskfree,
             compound=compound,
-            rolling_sharpe_window=rolling_sharpe_window)
+            rolling_sharpe_window=rolling_sharpe_window,
+        )
 
     @classmethod
-    def from_pnl_csv(cls, filepath_or_buffer,
-                     start_date=None,
-                     end_date=None,
-                     trim_outliers=None,
-                     how_to_aggregate=None,
-                     riskfree=0,
-                     compound=True,
-                     rolling_sharpe_window=200):
+    def from_pnl_csv(
+        cls,
+        filepath_or_buffer,
+        start_date=None,
+        end_date=None,
+        trim_outliers=None,
+        how_to_aggregate=None,
+        riskfree=0,
+        compound=True,
+        rolling_sharpe_window=200,
+    ):
         """
         Creates a DailyPerformance instance from a PNL CSV.
 
@@ -342,29 +352,17 @@ class DailyPerformance(object):
             how_to_aggregate=how_to_aggregate,
             riskfree=riskfree,
             compound=compound,
-            rolling_sharpe_window=rolling_sharpe_window)
+            rolling_sharpe_window=rolling_sharpe_window,
+        )
 
     @property
     def cum_returns(self):
+
         if self._cum_returns is None:
             self._cum_returns = get_cum_returns(self.returns, compound=self.compound)
 
         return self._cum_returns
 
-    @property
-    def cum_returns_longs(self):
-        if self._cum_returns_longs is None:
-            self._cum_returns_longs = get_cum_returns(self.returns_longs, compound=self.compound)
-
-        return self._cum_returns_longs
-
-    @property
-    def cum_returns_shorts(self):
-        if self._cum_returns_shorts is None:
-            self._cum_returns_shorts = get_cum_returns(self.returns_shorts, compound=self.compound)
-
-        return self._cum_returns_shorts
-
     @property
     def cum_commissions(self):
 
@@ -396,20 +394,6 @@ class DailyPerformance(object):
 
         return self._cagr
 
-    @property
-    def cagr_longs(self):
-        if self._cagr_longs is None:
-            self._cagr_longs = get_cagr(self.cum_returns_longs, compound=self.compound)
-
-        return self._cagr_longs
-
-    @property
-    def cagr_shorts(self):
-        if self._cagr_shorts is None:
-            self._cagr_shorts = get_cagr(self.cum_returns_shorts, compound=self.compound)
-
-        return self._cagr_shorts
-
     @property
     def sharpe(self):
         if self._sharpe is None:
@@ -421,9 +405,8 @@ class DailyPerformance(object):
     def rolling_sharpe(self):
         if self._rolling_sharpe is None:
             self._rolling_sharpe = get_rolling_sharpe(
-                self.returns,
-                window=self.rolling_sharpe_window,
-                riskfree=self.riskfree)
+                self.returns, window=self.rolling_sharpe_window, riskfree=self.riskfree
+            )
 
         return self._rolling_sharpe
 
@@ -466,7 +449,10 @@ class DailyPerformance(object):
         col = have_benchmarks.index[0]
         if len(have_benchmarks.index) > 1:
             import warnings
-            warnings.warn("Multiple benchmarks found, only using first ({0})".format(col))
+
+            warnings.warn(
+                "Multiple benchmarks found, only using first ({0})".format(col)
+            )
 
         benchmark_prices = self._benchmark_prices[col]
 
@@ -479,38 +465,12 @@ class DailyPerformance(object):
     def benchmark_cum_returns(self):
 
         if self._benchmark_cum_returns is None and self._benchmark_returns is not None:
-            self._benchmark_cum_returns = get_cum_returns(self._benchmark_returns, compound=True)
+            self._benchmark_cum_returns = get_cum_returns(
+                self._benchmark_returns, compound=True
+            )
 
         return self._benchmark_cum_returns
 
-    @property
-    def average_holding_periods_pos(self):
-        if self._average_holding_periods_pos is None:
-            self._average_holding_periods_pos = get_average_holding_periods(self.total_holdings)
-
-        return self._average_holding_periods_pos
-
-    @property
-    def average_holding_periods_null(self):
-        if self._average_holding_periods_null is None:
-            self._average_holding_periods_null = get_average_holding_periods(self.total_holdings, lambda x: x == 0)
-
-        return self._average_holding_periods_null
-
-    @property
-    def top_movers(self):
-        if self._top_movers is None:
-            self._top_movers = get_top_movers(self.returns)
-
-        return self._top_movers
-
-    @property
-    def bar_size(self):
-        if self._bar_size is None:
-            self._bar_size = get_bar_size(self.returns)
-
-        return self._bar_size
-
 
 class AggregateDailyPerformance(DailyPerformance):
     """
@@ -553,10 +513,14 @@ class AggregateDailyPerformance(DailyPerformance):
     >>> agg_perf.cum_returns.plot()
     """
 
-    def __init__(self, performance, riskfree=None,
-                 compound=None,
-                 rolling_sharpe_window=None,
-                 trim_outliers=None):
+    def __init__(
+        self,
+        performance,
+        riskfree=None,
+        compound=None,
+        rolling_sharpe_window=None,
+        trim_outliers=None,
+    ):
 
         if riskfree is None:
             riskfree = performance.riskfree
@@ -573,7 +537,7 @@ class AggregateDailyPerformance(DailyPerformance):
             compound=compound,
             rolling_sharpe_window=rolling_sharpe_window,
             benchmark=performance._benchmark_prices,
-            trim_outliers=trim_outliers
+            trim_outliers=trim_outliers,
         )
         if performance.pnl is not None:
             self.pnl = performance.pnl.sum(axis=1)
