@@ -1,4 +1,5 @@
-# Copyright 2019 QuantRocket LLC - All Rights Reserved
+# -*- coding: utf-8 -*-
+# Copyright 2017-2022 QuantRocket LLC - All Rights Reserved
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -12,19 +13,13 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import warnings
-
 import pandas as pd
-
 import matplotlib.pyplot as plt
 from matplotlib.font_manager import FontProperties
-
 import seaborn as sns
-
 import empyrical as ep
-
 import scipy.stats
-
+import warnings
 from .base import BaseTearsheet
 from .perf import DailyPerformance, AggregateDailyPerformance
 from .utils import with_baseline, get_cum_returns
@@ -40,24 +35,28 @@ class ShortfallTearsheet(BaseTearsheet):
     ShortfallTearsheet.from_csvs : Create a shortfall tear sheet from CSVs.
     """
 
-    def __init__(self,
-                 *args,
-                 labels=("simulated", "actual"),
-                 **kwargs):
+    def __init__(self, *args, labels=("simulated", "actual"), **kwargs):
         super().__init__(*args, **kwargs)
         self.x_label, self.y_label = labels
 
     @classmethod
-    def from_csvs(cls, x_filepath_or_buffer, y_filepath_or_buffer,
-                  labels=("simulated", "actual"),
-                  start_date=None,
-                  end_date=None,
-                  largest_n=None,
-                  shift_x_positions=0,
-                  figsize=None, trim_outliers=None,
-                  how_to_aggregate=None,
-                  pdf_filename=None, riskfree=0,
-                  compound=True, rolling_sharpe_window=200):
+    def from_csvs(
+        cls,
+        x_filepath_or_buffer,
+        y_filepath_or_buffer,
+        labels=("simulated", "actual"),
+        start_date=None,
+        end_date=None,
+        largest_n=None,
+        shift_x_positions=0,
+        figsize=None,
+        trim_outliers=None,
+        how_to_aggregate=None,
+        pdf_filename=None,
+        riskfree=0,
+        compound=True,
+        rolling_sharpe_window=200,
+    ):
         """
         Create a shortfall tear sheet comparing simulated results (or other benchmark results)
         with actual results.
@@ -127,7 +126,7 @@ class ShortfallTearsheet(BaseTearsheet):
 
         Examples
         --------
-        >>> from moonshot import ShortfallTearsheet
+        >>> from moonchart import ShortfallTearsheet
         >>> ShortfallTearsheet.from_csvs("backtest.csv", "pnl.csv")
         """
 
@@ -139,7 +138,8 @@ class ShortfallTearsheet(BaseTearsheet):
             how_to_aggregate=how_to_aggregate,
             riskfree=riskfree,
             compound=compound,
-            rolling_sharpe_window=rolling_sharpe_window)
+            rolling_sharpe_window=rolling_sharpe_window,
+        )
 
         y_perf = DailyPerformance.from_pnl_csv(
             y_filepath_or_buffer,
@@ -149,14 +149,17 @@ class ShortfallTearsheet(BaseTearsheet):
             how_to_aggregate=how_to_aggregate,
             riskfree=riskfree,
             compound=compound,
-            rolling_sharpe_window=rolling_sharpe_window)
+            rolling_sharpe_window=rolling_sharpe_window,
+        )
 
         t = cls(labels=labels, figsize=figsize, pdf_filename=pdf_filename)
-        return t.create_full_tearsheet(x_perf, y_perf, largest_n=largest_n,
-                                       shift_x_positions=shift_x_positions)
+        return t.create_full_tearsheet(
+            x_perf, y_perf, largest_n=largest_n, shift_x_positions=shift_x_positions
+        )
 
-    def create_full_tearsheet(self, x_performance, y_performance, largest_n=None,
-                              shift_x_positions=0):
+    def create_full_tearsheet(
+        self, x_performance, y_performance, largest_n=None, shift_x_positions=0
+    ):
         """
         Create a shortfall tear sheet comparing simulated results (or other
         benchmark results) with actual results.
@@ -201,75 +204,104 @@ class ShortfallTearsheet(BaseTearsheet):
         largest_shortfalls = None
         if largest_n:
             largest_shortfalls = self.create_largest_shortfalls_tearsheet(
-                x_performance, y_performance, largest_n=largest_n)
+                x_performance, y_performance, largest_n=largest_n
+            )
 
         # Returns
         self._plot_field(
             x_agg_performance.returns,
             y_agg_performance.returns,
             fig_title="Returns",
-            cumplots=True
+            cumplots=True,
         )
 
         if largest_shortfalls is not None:
             largest_shortfalls_x_mask = largest_shortfalls.shortfall.unstack().reindex(
-                index=x_performance.returns.index,
-                columns=x_performance.returns.columns)
+                index=x_performance.returns.index, columns=x_performance.returns.columns
+            )
             largest_shortfalls_y_mask = largest_shortfalls.shortfall.unstack().reindex(
-                index=y_performance.returns.index,
-                columns=y_performance.returns.columns)
+                index=y_performance.returns.index, columns=y_performance.returns.columns
+            )
 
             # Returns excluding largest shortfalls
             self._plot_field(
-                x_performance.returns.where(largest_shortfalls_x_mask.isnull(), 0).sum(axis=1),
-                y_performance.returns.where(largest_shortfalls_y_mask.isnull(), 0).sum(axis=1),
+                x_performance.returns.where(largest_shortfalls_x_mask.isnull(), 0).sum(
+                    axis=1
+                ),
+                y_performance.returns.where(largest_shortfalls_y_mask.isnull(), 0).sum(
+                    axis=1
+                ),
                 fig_title="Returns",
-                fig_title_suffix=" excluding Top {} Largest Shortfalls".format(largest_n),
-                cumplots=True
+                fig_title_suffix=" excluding Top {} Largest Shortfalls".format(
+                    largest_n
+                ),
+                cumplots=True,
             )
 
         # Commissions
-        if x_agg_performance.commissions is not None and y_agg_performance.commissions is not None:
+        if (
+            x_agg_performance.commissions is not None
+            and y_agg_performance.commissions is not None
+        ):
             self._plot_field(
                 x_agg_performance.commissions,
                 y_agg_performance.commissions,
                 fig_title="Commissions",
-                format_as_pct_decimal_places=2)
+                format_as_pct_decimal_places=2,
+            )
 
         # Total holdings
-        if x_agg_performance.total_holdings is not None and y_agg_performance.total_holdings is not None:
+        if (
+            x_agg_performance.total_holdings is not None
+            and y_agg_performance.total_holdings is not None
+        ):
             self._plot_field(
                 x_agg_performance.total_holdings.shift(shift_x_positions),
                 y_agg_performance.total_holdings,
                 fig_title="Total Holdings",
-                format_as_pct_decimal_places=None)
+                format_as_pct_decimal_places=None,
+            )
 
         # Net exposures
-        if x_agg_performance.net_exposures is not None and y_agg_performance.net_exposures is not None:
+        if (
+            x_agg_performance.net_exposures is not None
+            and y_agg_performance.net_exposures is not None
+        ):
             self._plot_field(
                 x_agg_performance.net_exposures.shift(shift_x_positions),
                 y_agg_performance.net_exposures,
-                fig_title="Net Exposure")
+                fig_title="Net Exposure",
+            )
 
         # Absolute exposures
-        if x_agg_performance.abs_exposures is not None and y_agg_performance.abs_exposures is not None:
+        if (
+            x_agg_performance.abs_exposures is not None
+            and y_agg_performance.abs_exposures is not None
+        ):
             self._plot_field(
                 x_agg_performance.abs_exposures.shift(shift_x_positions),
                 y_agg_performance.abs_exposures,
-                fig_title="Absolute Exposure")
+                fig_title="Absolute Exposure",
+            )
 
         # Turnover
-        if x_agg_performance.turnover is not None and y_agg_performance.turnover is not None:
+        if (
+            x_agg_performance.turnover is not None
+            and y_agg_performance.turnover is not None
+        ):
             self._plot_field(
                 x_agg_performance.turnover.shift(shift_x_positions),
                 y_agg_performance.turnover,
-                fig_title="Turnover")
+                fig_title="Turnover",
+            )
 
         self._save_or_show()
 
         return largest_shortfalls
 
-    def create_largest_shortfalls_tearsheet(self, x_performance, y_performance, largest_n=5):
+    def create_largest_shortfalls_tearsheet(
+        self, x_performance, y_performance, largest_n=5
+    ):
         """
         Create a "largest shortfalls" table highligting the dates and
         specific instruments or strategies (depending on whether the columns
@@ -293,10 +325,15 @@ class ShortfallTearsheet(BaseTearsheet):
             DataFrame of largest shortfalls
         """
 
-        shared_columns = x_performance.returns.columns.intersection(y_performance.returns.columns)
+        shared_columns = x_performance.returns.columns.intersection(
+            y_performance.returns.columns
+        )
         if shared_columns.empty:
-            warnings.warn("skipping largest shortfalls table because {x} and {y} have no shared columns".format(
-                x=self.x_label, y=self.y_label))
+            warnings.warn(
+                "skipping largest shortfalls table because {x} and {y} have no shared columns".format(
+                    x=self.x_label, y=self.y_label
+                )
+            )
             return
 
         x_returns = x_performance.returns.stack()
@@ -312,12 +349,16 @@ class ShortfallTearsheet(BaseTearsheet):
 
         returns = returns[returns.abs_shortfall > 0]
         if returns.empty:
-            warnings.warn("skipping largest shortfalls table because no shortfall found")
+            warnings.warn(
+                "skipping largest shortfalls table because no shortfall found"
+            )
             return None
 
-        largest_shortfalls = returns.sort_values(
-            "abs_shortfall", ascending=False).drop(
-                "abs_shortfall", axis=1).head(largest_n)
+        largest_shortfalls = (
+            returns.sort_values("abs_shortfall", ascending=False)
+            .drop("abs_shortfall", axis=1)
+            .head(largest_n)
+        )
 
         largest_shortfalls_raw = largest_shortfalls.copy()
 
@@ -329,7 +370,10 @@ class ShortfallTearsheet(BaseTearsheet):
         largest_shortfalls.insert(
             0,
             "Top {} Largest Shortfalls".format(largest_n),
-            largest_shortfalls.Date.dt.strftime("%Y-%m-%d").str.cat(largest_shortfalls.Sid, sep=" "))
+            largest_shortfalls.Date.dt.strftime("%Y-%m-%d").str.cat(
+                largest_shortfalls.Sid, sep=" "
+            ),
+        )
 
         largest_shortfalls = largest_shortfalls.drop(["Date", "Sid"], axis=1)
 
@@ -344,23 +388,29 @@ class ShortfallTearsheet(BaseTearsheet):
 
             table = axis.table(
                 colWidths=[0.4, 0.2, 0.2, 0.2],
-                cellText=[largest_shortfalls_dict["columns"]] + largest_shortfalls_dict["data"],
-                loc="center"
+                cellText=[largest_shortfalls_dict["columns"]]
+                + largest_shortfalls_dict["data"],
+                loc="center",
             )
 
             for (row, col), cell in table.get_celld().items():
                 if row == 0:
-                    cell.set_text_props(fontproperties=FontProperties(weight='bold'))
+                    cell.set_text_props(fontproperties=FontProperties(weight="bold"))
 
             table.scale(2, 2)
             table.set_fontsize("large")
 
         return largest_shortfalls_raw
 
-    def _plot_field(self, x, y, fig_title,
-                    fig_title_suffix="",
-                    format_as_pct_decimal_places=1,
-                    cumplots=False):
+    def _plot_field(
+        self,
+        x,
+        y,
+        fig_title,
+        fig_title_suffix="",
+        format_as_pct_decimal_places=1,
+        cumplots=False,
+    ):
 
         y.name = self.y_label
         x.name = self.x_label
@@ -378,17 +428,26 @@ class ShortfallTearsheet(BaseTearsheet):
             cum_results = get_cum_returns(results)
             cum_shortfall = cum_results[self.y_label] - cum_results[self.x_label]
 
-            cum_shortfall = pd.concat([
-                cum_shortfall.where(cum_shortfall > 0),
-                cum_shortfall.where(cum_shortfall < 0)
-            ], axis=1, keys=["positive", "negative"])
+            cum_shortfall = pd.concat(
+                [
+                    cum_shortfall.where(cum_shortfall > 0),
+                    cum_shortfall.where(cum_shortfall < 0),
+                ],
+                axis=1,
+                keys=["positive", "negative"],
+            )
 
             fig, (ax1, ax2, axis) = plt.subplots(
-                3, 1, sharex=True, gridspec_kw={
-                    "height_ratios": [0.5, 0.25, 0.25],
-                    'hspace': 0.1},
-                num="Cumulative " + fig_title + fig_title_suffix, figsize=self.figsize)
-            with_baseline(cum_results).plot(ax=ax1, title="Cumulative " + fig_title + fig_title_suffix)
+                3,
+                1,
+                sharex=True,
+                gridspec_kw={"height_ratios": [0.5, 0.25, 0.25], "hspace": 0.1},
+                num="Cumulative " + fig_title + fig_title_suffix,
+                figsize=self.figsize,
+            )
+            with_baseline(cum_results).plot(
+                ax=ax1, title="Cumulative " + fig_title + fig_title_suffix
+            )
             self._y_format_at_least_two_decimal_places(ax1)
             ax1.set_ylabel("Cumulative " + fig_title)
             ax1.set_xlabel("")
@@ -397,10 +456,12 @@ class ShortfallTearsheet(BaseTearsheet):
             self._y_format_as_percentage(ax2, max_decimal_places=2)
             ax2.set_ylabel("Percentage of capital")
             with_baseline(cum_shortfall, value=0).plot(
-                ax=ax2, title="Cumulative Shortfall", kind="area",
+                ax=ax2,
+                title="Cumulative Shortfall",
+                kind="area",
                 stacked=False,
                 legend=False,
-                color=["C1", "C2"]  # 2nd and 3rd color in palette are green and red
+                color=["C1", "C2"],  # 2nd and 3rd color in palette are green and red
             )
             ax2.set_xlabel("")
 
@@ -410,7 +471,9 @@ class ShortfallTearsheet(BaseTearsheet):
             axis = fig.add_subplot(111)
 
         if format_as_pct_decimal_places is not None:
-            self._y_format_as_percentage(axis, max_decimal_places=format_as_pct_decimal_places)
+            self._y_format_as_percentage(
+                axis, max_decimal_places=format_as_pct_decimal_places
+            )
             axis.set_ylabel("Percentage of capital")
 
         shortfall = results[self.y_label] - results[self.x_label]
@@ -439,97 +502,249 @@ class ShortfallTearsheet(BaseTearsheet):
         stats = []
 
         stats.append(
-            ["Start Date",
-             [x_performance.returns.index.min().date().isoformat(),
-              y_performance.returns.index.min().date().isoformat()]])
+            [
+                "Start Date",
+                [
+                    x_performance.returns.index.min().date().isoformat(),
+                    y_performance.returns.index.min().date().isoformat(),
+                ],
+            ]
+        )
         stats.append(
-            ["End Date",
-             [x_performance.returns.index.max().date().isoformat(),
-              y_performance.returns.index.max().date().isoformat()]])
+            [
+                "End Date",
+                [
+                    x_performance.returns.index.max().date().isoformat(),
+                    y_performance.returns.index.max().date().isoformat(),
+                ],
+            ]
+        )
 
         stats.append(
-            ['Total Months',
-             [round((x_performance.returns.index.max() -
-                     x_performance.returns.index.min()) /
-                    pd.Timedelta(365.25 / 12, 'D')),
-              round((y_performance.returns.index.max() -
-                     y_performance.returns.index.min()) /
-                    pd.Timedelta(365.25 / 12, 'D'))]])
+            [
+                "Total Months",
+                [
+                    round(
+                        (
+                            x_performance.returns.index.max()
+                            - x_performance.returns.index.min()
+                        )
+                        / pd.Timedelta(365.25 / 12, "D")
+                    ),
+                    round(
+                        (
+                            y_performance.returns.index.max()
+                            - y_performance.returns.index.min()
+                        )
+                        / pd.Timedelta(365.25 / 12, "D")
+                    ),
+                ],
+            ]
+        )
 
         stats.append([" Risk and Returns", ["", ""]])
-        stats.append([
-            "CAGR",
-            ["{0}%".format(round(x_performance.cagr * 100, 1)),
-             "{0}%".format(round(y_performance.cagr * 100, 1))]])
-        stats.append([
-            "Sharpe Ratio",
-            ['%.2f' % x_performance.sharpe,
-             '%.2f' % y_performance.sharpe]])
-        stats.append([
-            "Max Drawdown",
-            ["{0}%".format(round(x_performance.max_drawdown * 100, 1)),
-             "{0}%".format(round(y_performance.max_drawdown * 100, 1))]])
-        stats.append([
-            "Cumulative Return",
-            ["{0}%".format(round(ep.cum_returns_final(x_performance.returns) * 100, 1)),
-             "{0}%".format(round(ep.cum_returns_final(y_performance.returns) * 100, 1))]])
-        if x_performance.commissions is not None and y_performance.commissions is not None:
-            stats.append([
-                "Cumulative Commissions",
-                ["{0}%".format(round(ep.cum_returns_final(x_performance.commissions) * 100, 1)),
-                 "{0}%".format(round(ep.cum_returns_final(y_performance.commissions) * 100, 1))]])
-        stats.append([
-            "Annual Volatility",
-            ["{0}%".format(round(ep.annual_volatility(x_performance.returns) * 100, 1)),
-             "{0}%".format(round(ep.annual_volatility(y_performance.returns) * 100, 1))]])
-        stats.append([
-            "Sortino Ratio",
-            ['%.2f' % ep.sortino_ratio(x_performance.returns),
-             '%.2f' % ep.sortino_ratio(y_performance.returns)]])
-        stats.append([
-            "Calmar Ratio",
-            ['%.2f' % ep.calmar_ratio(x_performance.returns),
-             '%.2f' % ep.calmar_ratio(y_performance.returns)]])
-        stats.append([
-            "Skew",
-            ['%.2f' % scipy.stats.skew(x_performance.returns),
-             '%.2f' % scipy.stats.skew(y_performance.returns)]])
-        stats.append([
-            "Kurtosis",
-            ['%.2f' % scipy.stats.kurtosis(x_performance.returns),
-             '%.2f' % scipy.stats.kurtosis(y_performance.returns)]])
+        stats.append(
+            [
+                "CAGR",
+                [
+                    "{0}%".format(round(x_performance.cagr * 100, 1)),
+                    "{0}%".format(round(y_performance.cagr * 100, 1)),
+                ],
+            ]
+        )
+        stats.append(
+            [
+                "Sharpe Ratio",
+                ["%.2f" % x_performance.sharpe, "%.2f" % y_performance.sharpe],
+            ]
+        )
+        stats.append(
+            [
+                "Max Drawdown",
+                [
+                    "{0}%".format(round(x_performance.max_drawdown * 100, 1)),
+                    "{0}%".format(round(y_performance.max_drawdown * 100, 1)),
+                ],
+            ]
+        )
+        stats.append(
+            [
+                "Cumulative Return",
+                [
+                    "{0}%".format(
+                        round(ep.cum_returns_final(x_performance.returns) * 100, 1)
+                    ),
+                    "{0}%".format(
+                        round(ep.cum_returns_final(y_performance.returns) * 100, 1)
+                    ),
+                ],
+            ]
+        )
+        if (
+            x_performance.commissions is not None
+            and y_performance.commissions is not None
+        ):
+            stats.append(
+                [
+                    "Cumulative Commissions",
+                    [
+                        "{0}%".format(
+                            round(
+                                ep.cum_returns_final(x_performance.commissions) * 100, 1
+                            )
+                        ),
+                        "{0}%".format(
+                            round(
+                                ep.cum_returns_final(y_performance.commissions) * 100, 1
+                            )
+                        ),
+                    ],
+                ]
+            )
+        stats.append(
+            [
+                "Annual Volatility",
+                [
+                    "{0}%".format(
+                        round(ep.annual_volatility(x_performance.returns) * 100, 1)
+                    ),
+                    "{0}%".format(
+                        round(ep.annual_volatility(y_performance.returns) * 100, 1)
+                    ),
+                ],
+            ]
+        )
+        stats.append(
+            [
+                "Sortino Ratio",
+                [
+                    "%.2f" % ep.sortino_ratio(x_performance.returns),
+                    "%.2f" % ep.sortino_ratio(y_performance.returns),
+                ],
+            ]
+        )
+        stats.append(
+            [
+                "Calmar Ratio",
+                [
+                    "%.2f" % ep.calmar_ratio(x_performance.returns),
+                    "%.2f" % ep.calmar_ratio(y_performance.returns),
+                ],
+            ]
+        )
+        stats.append(
+            [
+                "Skew",
+                [
+                    "%.2f" % scipy.stats.skew(x_performance.returns),
+                    "%.2f" % scipy.stats.skew(y_performance.returns),
+                ],
+            ]
+        )
+        stats.append(
+            [
+                "Kurtosis",
+                [
+                    "%.2f" % scipy.stats.kurtosis(x_performance.returns),
+                    "%.2f" % scipy.stats.kurtosis(y_performance.returns),
+                ],
+            ]
+        )
 
         stats.append([" Positions and Exposure", ["", ""]])
 
-        if x_performance.abs_exposures is not None and y_performance.abs_exposures is not None:
-            stats.append([
-                "Absolute Exposure (percentage of capital)",
-                ["{0}%".format(round(x_performance.abs_exposures.mean() * 100, 1)),
-                 "{0}%".format(round(y_performance.abs_exposures.mean() * 100, 1))]])
+        if (
+            x_performance.abs_exposures is not None
+            and y_performance.abs_exposures is not None
+        ):
+            stats.append(
+                [
+                    "Absolute Exposure (percentage of capital)",
+                    [
+                        "{0}%".format(
+                            round(x_performance.abs_exposures.mean() * 100, 1)
+                        ),
+                        "{0}%".format(
+                            round(y_performance.abs_exposures.mean() * 100, 1)
+                        ),
+                    ],
+                ]
+            )
 
-        if x_performance.net_exposures is not None and y_performance.net_exposures is not None:
-            stats.append([
-                "Net Exposure (percentage of capital)",
-                ["{0}%".format(round(x_performance.net_exposures.mean() * 100, 1)),
-                 "{0}%".format(round(y_performance.net_exposures.mean() * 100, 1))]])
+        if (
+            x_performance.net_exposures is not None
+            and y_performance.net_exposures is not None
+        ):
+            stats.append(
+                [
+                    "Net Exposure (percentage of capital)",
+                    [
+                        "{0}%".format(
+                            round(x_performance.net_exposures.mean() * 100, 1)
+                        ),
+                        "{0}%".format(
+                            round(y_performance.net_exposures.mean() * 100, 1)
+                        ),
+                    ],
+                ]
+            )
 
-        if x_performance.total_holdings is not None and y_performance.total_holdings is not None:
-            stats.append([
-                "Average Daily Holdings",
-                [round(x_performance.total_holdings.mean()),
-                 round(y_performance.total_holdings.mean())]])
+        if (
+            x_performance.total_holdings is not None
+            and y_performance.total_holdings is not None
+        ):
+            stats.append(
+                [
+                    "Average Daily Holdings",
+                    [
+                        round(x_performance.total_holdings.mean()),
+                        round(y_performance.total_holdings.mean()),
+                    ],
+                ]
+            )
 
         if x_performance.turnover is not None and y_performance.turnover is not None:
-            stats.append([
-                "Average Daily Turnover (percentage of capital)",
-                ["{0}%".format(round(x_performance.turnover.mean() * 100, 1)),
-                 "{0}%".format(round(y_performance.turnover.mean() * 100, 1))]])
+            stats.append(
+                [
+                    "Average Daily Turnover (percentage of capital)",
+                    [
+                        "{0}%".format(round(x_performance.turnover.mean() * 100, 1)),
+                        "{0}%".format(round(y_performance.turnover.mean() * 100, 1)),
+                    ],
+                ]
+            )
 
-        if x_performance.abs_exposures is not None and y_performance.abs_exposures is not None:
-            stats.append([
-                "Normalized CAGR (CAGR/Absolute Exposure)",
-                ["{0}%".format(round((x_performance.cagr / x_performance.abs_exposures.mean()) * 100, 1)),
-                 "{0}%".format(round((y_performance.cagr / y_performance.abs_exposures.mean()) * 100, 1))]])
+        if (
+            x_performance.abs_exposures is not None
+            and y_performance.abs_exposures is not None
+        ):
+            stats.append(
+                [
+                    "Normalized CAGR (CAGR/Absolute Exposure)",
+                    [
+                        "{0}%".format(
+                            round(
+                                (
+                                    x_performance.cagr
+                                    / x_performance.abs_exposures.mean()
+                                )
+                                * 100,
+                                1,
+                            )
+                        ),
+                        "{0}%".format(
+                            round(
+                                (
+                                    y_performance.cagr
+                                    / y_performance.abs_exposures.mean()
+                                )
+                                * 100,
+                                1,
+                            )
+                        ),
+                    ],
+                ]
+            )
 
         with sns.axes_style("white"):
 
@@ -544,12 +759,12 @@ class ShortfallTearsheet(BaseTearsheet):
                 cellText=values,
                 rowLabels=headings,
                 colLabels=[self.x_label, self.y_label],
-                loc="center"
+                loc="center",
             )
             for (row, col), cell in table.get_celld().items():
                 txt = cell.get_text().get_text()
                 if row == 0 or txt.startswith(" "):
-                    cell.set_text_props(fontproperties=FontProperties(weight='bold'))
+                    cell.set_text_props(fontproperties=FontProperties(weight="bold"))
 
             table.scale(1, 2)
             table.set_fontsize("large")
