@@ -1,4 +1,5 @@
-# Copyright 2017 QuantRocket LLC - All Rights Reserved
+# -*- coding: utf-8 -*-
+# Copyright 2017-2022 QuantRocket LLC - All Rights Reserved
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -12,38 +13,40 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import math
-import warnings
-
 import numpy as np
-
 import pandas as pd
-
 import seaborn as sns
-
 import matplotlib.pyplot as plt
 from matplotlib.font_manager import FontProperties
-
+import math
+import warnings
 import empyrical as ep
-
 import scipy.stats
-
-from .utils import *
-from .base import BaseTearsheet
-from linefolio import from_moonshot
 from .perf import DailyPerformance, AggregateDailyPerformance
+from .base import BaseTearsheet
+from .utils import with_baseline, get_sharpe, get_cagr, get_cum_returns, get_drawdowns
 
 
 class Tearsheet(BaseTearsheet):
     """
     Generates a tear sheet of performance stats and graphs.
     """
+
     @classmethod
-    def from_moonshot_csv(cls, filepath_or_buffer, figsize=None,
-                          max_cols_for_details=25, trim_outliers=None,
-                          how_to_aggregate=None,
-                          pdf_filename=None, riskfree=0,
-                          compound=True, rolling_sharpe_window=200):
+    def from_moonshot_csv(
+        cls,
+        filepath_or_buffer,
+        figsize=None,
+        max_cols_for_details=25,
+        trim_outliers=None,
+        how_to_aggregate=None,
+        pdf_filename=None,
+        riskfree=0,
+        start_date=None,
+        end_date=None,
+        compound=True,
+        rolling_sharpe_window=200,
+    ):
         """
         Create a full tear sheet from a moonshot backtest results CSV.
 
@@ -76,6 +79,12 @@ class Tearsheet(BaseTearsheet):
         riskfree : float, optional
             the riskfree rate (default 0)
 
+        start_date : str (YYYY-MM-DD), optional
+            truncate at this start date (otherwise include entire date range)
+
+        end_date : str (YYYY-MM-DD), optional
+            truncate at this end date (otherwise include entire date range)
+
         compound : bool
             True for compound/geometric returns, False for arithmetic returns.
             Default True
@@ -89,29 +98,43 @@ class Tearsheet(BaseTearsheet):
 
         Examples
         --------
-        >>> from moonshot import Tearsheet
+        >>> from moonchart import Tearsheet
         >>> Tearsheet.from_moonshot_csv("backtest_results.csv")
         """
         perf = DailyPerformance.from_moonshot_csv(
             filepath_or_buffer,
+            start_date=start_date,
+            end_date=end_date,
             trim_outliers=trim_outliers,
             how_to_aggregate=how_to_aggregate,
             riskfree=riskfree,
             compound=compound,
-            rolling_sharpe_window=rolling_sharpe_window)
+            rolling_sharpe_window=rolling_sharpe_window,
+        )
 
-        t = cls(figsize=figsize,
-                max_cols_for_details=max_cols_for_details,
-                pdf_filename=pdf_filename)
+        t = cls(
+            figsize=figsize,
+            max_cols_for_details=max_cols_for_details,
+            pdf_filename=pdf_filename,
+        )
 
         return t.create_full_tearsheet(perf)
 
     @classmethod
-    def from_pnl_csv(cls, filepath_or_buffer, figsize=None,
-                     max_cols_for_details=25, trim_outliers=None,
-                     how_to_aggregate=None,
-                     pdf_filename=None, riskfree=0,
-                     compound=True, rolling_sharpe_window=200):
+    def from_pnl_csv(
+        cls,
+        filepath_or_buffer,
+        figsize=None,
+        max_cols_for_details=25,
+        trim_outliers=None,
+        how_to_aggregate=None,
+        pdf_filename=None,
+        riskfree=0,
+        start_date=None,
+        end_date=None,
+        compound=True,
+        rolling_sharpe_window=200,
+    ):
         """
         Create a full tear sheet from a pnl CSV.
 
@@ -143,6 +166,12 @@ class Tearsheet(BaseTearsheet):
         riskfree : float, optional
             the riskfree rate (default 0)
 
+        start_date : str (YYYY-MM-DD), optional
+            truncate at this start date (otherwise include entire date range)
+
+        end_date : str (YYYY-MM-DD), optional
+            truncate at this end date (otherwise include entire date range)
+
         compound : bool
             True for compound/geometric returns, False for arithmetic returns.
             Default True
@@ -156,15 +185,20 @@ class Tearsheet(BaseTearsheet):
         """
         perf = DailyPerformance.from_pnl_csv(
             filepath_or_buffer,
+            start_date=start_date,
+            end_date=end_date,
             trim_outliers=trim_outliers,
             how_to_aggregate=how_to_aggregate,
             riskfree=riskfree,
             compound=compound,
-            rolling_sharpe_window=rolling_sharpe_window)
+            rolling_sharpe_window=rolling_sharpe_window,
+        )
 
-        t = cls(figsize=figsize,
-                max_cols_for_details=max_cols_for_details,
-                pdf_filename=pdf_filename)
+        t = cls(
+            figsize=figsize,
+            max_cols_for_details=max_cols_for_details,
+            pdf_filename=pdf_filename,
+        )
 
         return t.create_full_tearsheet(perf)
 
@@ -197,23 +231,26 @@ class Tearsheet(BaseTearsheet):
 
         num_cols = len(performance.returns.columns)
         if num_cols > self.max_cols_for_details:
-            warnings.warn("Suppressing details because there are more than {0} columns "
-                          "(you can control this setting by modifying "
-                          "Tearsheet.max_cols_for_details)".format(
-                              self.max_cols_for_details))
+            warnings.warn(
+                "Suppressing details because there are more than {0} columns "
+                "(you can control this setting by modifying "
+                "Tearsheet.max_cols_for_details)".format(self.max_cols_for_details)
+            )
 
         self.create_summary_tearsheet(performance, agg_performance)
         self.create_returns_tearsheet(performance, agg_performance)
         self.create_returns_by_year_tearsheet(performance, agg_performance)
 
-        if any([exposures is not None for exposures in (
-                performance.net_exposures, performance.abs_exposures)]):
+        if any(
+            [
+                exposures is not None
+                for exposures in (performance.net_exposures, performance.abs_exposures)
+            ]
+        ):
             self.create_positions_tearsheet(performance, agg_performance)
 
         self._create_constituents_tearsheet(performance)
 
-        from_moonshot(performance.results)
-
         self._save_or_show()
 
     def create_summary_tearsheet(self, performance, agg_performance=None):
@@ -248,92 +285,122 @@ class Tearsheet(BaseTearsheet):
         if agg_performance.pnl is not None:
             stats.append(["PNL", round(agg_performance.pnl.sum(), 2)])
         if agg_performance.commission_amounts is not None:
-            stats.append(["Commissions", round(agg_performance.commission_amounts.sum(), 2)])
+            stats.append(
+                ["Commissions", round(agg_performance.commission_amounts.sum(), 2)]
+            )
 
-        stats.append(["Start Date", agg_performance.returns.index.min().date().isoformat()])
-        stats.append(["End Date", agg_performance.returns.index.max().date().isoformat()])
+        stats.append(
+            ["Start Date", agg_performance.returns.index.min().date().isoformat()]
+        )
+        stats.append(
+            ["End Date", agg_performance.returns.index.max().date().isoformat()]
+        )
 
-        stats.append(['Total Months', round((agg_performance.returns.index.max() -
-                                             agg_performance.returns.index.min()) /
-                                            pd.Timedelta(365.25 / 12, 'D'))])
+        stats.append(
+            [
+                "Total Months",
+                round(
+                    (
+                        agg_performance.returns.index.max()
+                        - agg_performance.returns.index.min()
+                    )
+                    / pd.Timedelta(365.25 / 12, "D")
+                ),
+            ]
+        )
 
         stats.append(["", " Risk and Returns"])
         stats.append(["CAGR", "{0}%".format(round(agg_performance.cagr * 100, 1))])
-        stats.append([
-            "Sharpe Ratio",
-            '%.2f' % agg_performance.sharpe])
-        stats.append([
-            "Max Drawdown",
-            "{0}%".format(round(agg_performance.max_drawdown * 100, 1))])
-        stats.append([
-            "Cumulative Return",
-            "{0}%".format(round(ep.cum_returns_final(agg_performance.returns) * 100, 1))])
-        stats.append([
-            "Annual Volatility",
-            "{0}%".format(round(ep.annual_volatility(agg_performance.returns) * 100, 1))])
-        stats.append([
-            "Sortino Ratio",
-            '%.2f' % ep.sortino_ratio(agg_performance.returns)])
-        stats.append([
-            "Calmar Ratio",
-            '%.2f' % ep.calmar_ratio(agg_performance.returns)])
-        stats.append([
-            "Skew",
-            '%.2f' % scipy.stats.skew(agg_performance.returns)])
-        stats.append([
-            "Kurtosis",
-            '%.2f' % scipy.stats.kurtosis(agg_performance.returns)])
-        stats.append(["Biggest Individual Win", "{:3.2f}%".format(agg_performance.top_movers.max() * 100)])
-        stats.append(["Biggest Individual Loss", "{:3.2f}%".format(agg_performance.top_movers.min() * 100)])
+        stats.append(["Sharpe Ratio", "%.2f" % agg_performance.sharpe])
+        stats.append(
+            [
+                "Max Drawdown",
+                "{0}%".format(round(agg_performance.max_drawdown * 100, 1)),
+            ]
+        )
+        stats.append(
+            [
+                "Cumulative Return",
+                "{0}%".format(
+                    round(ep.cum_returns_final(agg_performance.returns) * 100, 1)
+                ),
+            ]
+        )
+        stats.append(
+            [
+                "Annual Volatility",
+                "{0}%".format(
+                    round(ep.annual_volatility(agg_performance.returns) * 100, 1)
+                ),
+            ]
+        )
+        stats.append(
+            ["Sortino Ratio", "%.2f" % ep.sortino_ratio(agg_performance.returns)]
+        )
+        stats.append(
+            ["Calmar Ratio", "%.2f" % ep.calmar_ratio(agg_performance.returns)]
+        )
+        stats.append(["Skew", "%.2f" % scipy.stats.skew(agg_performance.returns)])
+        stats.append(
+            ["Kurtosis", "%.2f" % scipy.stats.kurtosis(agg_performance.returns)]
+        )
 
-        if any([field is not None for field in (
-            agg_performance.abs_exposures,
-            agg_performance.net_exposures,
-            agg_performance.total_holdings,
-            agg_performance.turnover
-        )]):
+        if any(
+            [
+                field is not None
+                for field in (
+                    agg_performance.abs_exposures,
+                    agg_performance.net_exposures,
+                    agg_performance.total_holdings,
+                    agg_performance.turnover,
+                )
+            ]
+        ):
             stats.append(["", " Positions and Exposure"])
 
         if agg_performance.abs_exposures is not None:
             avg_abs_exposures = agg_performance.abs_exposures.mean()
-            stats.append([
-                "Absolute Exposure (percentage of capital)",
-                "{0}%".format(round(avg_abs_exposures * 100, 1))])
+            stats.append(
+                [
+                    "Absolute Exposure (percentage of capital)",
+                    "{0}%".format(round(avg_abs_exposures * 100, 1)),
+                ]
+            )
 
         if agg_performance.net_exposures is not None:
             avg_net_exposures = agg_performance.net_exposures.mean()
-            stats.append([
-                "Net Exposure (percentage of capital)",
-                "{0}%".format(round(avg_net_exposures * 100, 1))])
+            stats.append(
+                [
+                    "Net Exposure (percentage of capital)",
+                    "{0}%".format(round(avg_net_exposures * 100, 1)),
+                ]
+            )
 
         if agg_performance.total_holdings is not None:
             avg_daily_holdings = agg_performance.total_holdings.mean()
-            stats.append([
-                "Average Daily Holdings",
-                round(avg_daily_holdings)])
+            stats.append(["Average Daily Holdings", round(avg_daily_holdings)])
 
         if agg_performance.turnover is not None:
             avg_daily_turnover = agg_performance.turnover.mean()
-            stats.append([
-                "Average Daily Turnover (percentage of capital)",
-                "{0}%".format(round(avg_daily_turnover * 100, 1))])
+            stats.append(
+                [
+                    "Average Daily Turnover (percentage of capital)",
+                    "{0}%".format(round(avg_daily_turnover * 100, 1)),
+                ]
+            )
 
         if agg_performance.abs_exposures is not None:
             norm_cagr = agg_performance.cagr / avg_abs_exposures
-            stats.append([
-                "Normalized CAGR (CAGR/Absolute Exposure)",
-                "{0}%".format(round(norm_cagr * 100, 1))])
-
-        if agg_performance.total_holdings is not None:
-            stats.append(["", " Average Holding Periods"])
-            for index, (v_min, v_max, v_avg) in performance.average_holding_periods_pos \
-                    .sort_values("Avg", ascending=False) \
-                    .iloc[:3].sort_index().iterrows():
-                stats.append(["Average Holding Period {} - Avg".format(index), round(v_avg)])
+            stats.append(
+                [
+                    "Normalized CAGR (CAGR/Absolute Exposure)",
+                    "{0}%".format(round(norm_cagr * 100, 1)),
+                ]
+            )
 
         with sns.axes_style("white"):
 
-            fig = plt.figure("Performance Summary - Linechart", figsize=(6, 6))
+            fig = plt.figure("Performance Summary", figsize=(6, 6))
 
             axis = fig.add_subplot(111)
             axis.axis("off")
@@ -344,12 +411,12 @@ class Tearsheet(BaseTearsheet):
                 cellText=[[v] for v in values],
                 rowLabels=headings,
                 colLabels=["Performance Summary"],
-                loc="center"
+                loc="center",
             )
             for (row, col), cell in table.get_celld().items():
                 txt = cell.get_text().get_text()
                 if row == 0 or txt.startswith(" "):
-                    cell.set_text_props(fontproperties=FontProperties(weight='bold'))
+                    cell.set_text_props(fontproperties=FontProperties(weight="bold"))
 
             table.scale(1, 2)
             table.set_fontsize("large")
@@ -381,12 +448,15 @@ class Tearsheet(BaseTearsheet):
                     cells.append("")
 
             table = axis.table(
-                cellText=[cells[i:i + cells_per_row] for i in range(0, len(cells), cells_per_row)],
-                loc="top"
+                cellText=[
+                    cells[i : i + cells_per_row]
+                    for i in range(0, len(cells), cells_per_row)
+                ],
+                loc="top",
             )
             for (row, col), cell in table.get_celld().items():
                 if (row == 0) and (col == 0):
-                    cell.set_text_props(fontproperties=FontProperties(weight='bold'))
+                    cell.set_text_props(fontproperties=FontProperties(weight="bold"))
 
             table.scale(2, 2)
             table.set_fontsize("large")
@@ -437,10 +507,13 @@ class Tearsheet(BaseTearsheet):
             agg_performance,
             subplot=211 if show_details else 111,
             extra_label="(Aggregate)" if show_details else "",
-            figsize=(width, height))
+            figsize=(width, height),
+        )
 
         if show_details:
-            self._create_returns_plots(performance, subplot=212, extra_label="(Details)")
+            self._create_returns_plots(
+                performance, subplot=212, extra_label="(Details)"
+            )
             self._create_detailed_returns_bar_charts(performance)
 
     def _create_detailed_returns_bar_charts(self, performance):
@@ -477,35 +550,6 @@ class Tearsheet(BaseTearsheet):
 
         fig.tight_layout()
 
-        fig = plt.figure("Biggest Movers", figsize=self.figsize)
-
-        color_palette = sns.color_palette()
-        num_series = len(performance.cum_returns.columns)
-        if num_series > 6:
-            color_palette = sns.color_palette("hls", num_series)
-
-        top_movers = performance.top_movers
-        top_winners = top_movers[top_movers > 0].sort_index()
-        top_losers = top_movers[top_movers < 0].sort_index()
-
-        with sns.color_palette(sns.light_palette("red")):
-            axis = fig.add_subplot(2, 2, 1)
-            axis.set_ylabel("Losses")
-            self._y_format_as_percentage(axis)
-            loss = top_losers.copy().unstack()
-            ax = loss.plot(ax=axis, kind="bar", title="Biggest Losers")
-            ax.xaxis.set_major_formatter(plt.FixedFormatter(loss.index.to_series().dt.strftime("%Y-%m-%d")))
-
-        with sns.color_palette(sns.light_palette("green")):
-            axis = fig.add_subplot(2, 2, 2)
-            axis.set_ylabel("Wins")
-            self._y_format_as_percentage(axis)
-            win = top_winners.copy().unstack()
-            ax = win.plot(ax=axis, kind="bar", title="Biggest Winners")
-            ax.xaxis.set_major_formatter(plt.FixedFormatter(win.index.to_series().dt.strftime("%Y-%m-%d")))
-
-        fig.tight_layout()
-
         if performance.pnl is not None:
             fig = plt.figure("PNL (Details)", figsize=self.figsize)
             axis = fig.add_subplot(111)
@@ -518,7 +562,9 @@ class Tearsheet(BaseTearsheet):
                 gross_pnl = pnl + commission_amounts
                 gross_pnl.name = "gross pnl"
                 try:
-                    pnl = pd.concat((pnl, gross_pnl, commission_amounts), axis=1, sort=True)
+                    pnl = pd.concat(
+                        (pnl, gross_pnl, commission_amounts), axis=1, sort=True
+                    )
                 except TypeError:
                     # sort was introduced in pandas 0.23
                     pnl = pd.concat((pnl, gross_pnl, commission_amounts), axis=1)
@@ -566,10 +612,13 @@ class Tearsheet(BaseTearsheet):
             agg_performance,
             subplot=211 if show_details else 111,
             extra_label="(Aggregate)" if show_details else "",
-            figsize=(width, height))
+            figsize=(width, height),
+        )
 
         if show_details:
-            self._create_positions_plots(performance, subplot=212, extra_label="(Details)")
+            self._create_positions_plots(
+                performance, subplot=212, extra_label="(Details)"
+            )
             self._create_detailed_positions_bar_charts(performance)
 
     def _create_positions_plots(self, performance, subplot, extra_label, figsize=None):
@@ -590,7 +639,8 @@ class Tearsheet(BaseTearsheet):
                 axis = fig.add_subplot(subplot)
                 self._y_format_as_percentage(axis)
                 plot = performance.abs_exposures.round(2).plot(
-                    ax=axis, title="Absolute Exposure {0}".format(extra_label))
+                    ax=axis, title="Absolute Exposure {0}".format(extra_label)
+                )
                 axis.set_ylabel("Percentage of capital")
                 axis.set_xlabel("")
                 if isinstance(performance.abs_exposures, pd.DataFrame):
@@ -600,7 +650,9 @@ class Tearsheet(BaseTearsheet):
                 fig = plt.figure("Net Exposure", figsize=figsize)
                 axis = fig.add_subplot(subplot)
                 self._y_format_as_percentage(axis)
-                plot = performance.net_exposures.round(2).plot(ax=axis, title="Net Exposure {0}".format(extra_label))
+                plot = performance.net_exposures.round(2).plot(
+                    ax=axis, title="Net Exposure {0}".format(extra_label)
+                )
                 axis.set_ylabel("Percentage of capital")
                 axis.set_xlabel("")
                 if isinstance(performance.net_exposures, pd.DataFrame):
@@ -609,7 +661,9 @@ class Tearsheet(BaseTearsheet):
             if performance.total_holdings is not None:
                 fig = plt.figure("Daily Holdings", figsize=figsize)
                 axis = fig.add_subplot(subplot)
-                plot = performance.total_holdings.plot(ax=axis, title="Daily Holdings {0}".format(extra_label))
+                plot = performance.total_holdings.plot(
+                    ax=axis, title="Daily Holdings {0}".format(extra_label)
+                )
                 axis.set_ylabel("Number of holdings")
                 axis.set_xlabel("")
                 if isinstance(performance.total_holdings, pd.DataFrame):
@@ -620,7 +674,9 @@ class Tearsheet(BaseTearsheet):
                 axis = fig.add_subplot(subplot)
                 self._y_format_as_percentage(axis)
                 turnover = performance.turnover
-                plot = turnover.plot(ax=axis, title="Daily Turnover {0}".format(extra_label))
+                plot = turnover.plot(
+                    ax=axis, title="Daily Turnover {0}".format(extra_label)
+                )
                 axis.set_ylabel("Percentage of capital")
                 axis.set_xlabel("")
                 if isinstance(turnover, pd.DataFrame):
@@ -639,14 +695,19 @@ class Tearsheet(BaseTearsheet):
         if num_series > 6:
             color_palette = sns.color_palette("hls", num_series)
 
-        total_plots = sum([1 for field in (
-            performance.abs_exposures,
-            performance.net_exposures,
-            performance.total_holdings,
-            performance.turnover,
-            performance.abs_exposures) if field is not None])
-        if performance.total_holdings is not None:
-            total_plots += 2
+        total_plots = sum(
+            [
+                1
+                for field in (
+                    performance.abs_exposures,
+                    performance.net_exposures,
+                    performance.total_holdings,
+                    performance.turnover,
+                    performance.abs_exposures,
+                )
+                if field is not None
+            ]
+        )
 
         rows = math.ceil(total_plots / 2)
 
@@ -659,7 +720,9 @@ class Tearsheet(BaseTearsheet):
                 axis = fig.add_subplot(rows, 2, next_pos)
                 next_pos += 1
                 self._y_format_as_percentage(axis)
-                avg_abs_exposures.plot(ax=axis, kind="bar", title="Avg Absolute Exposure (Details)")
+                avg_abs_exposures.plot(
+                    ax=axis, kind="bar", title="Avg Absolute Exposure (Details)"
+                )
                 axis.set_ylabel("Percentage of capital")
 
             if performance.net_exposures is not None:
@@ -667,14 +730,18 @@ class Tearsheet(BaseTearsheet):
                 axis = fig.add_subplot(rows, 2, next_pos)
                 next_pos += 1
                 self._y_format_as_percentage(axis)
-                avg_net_exposures.plot(ax=axis, kind="bar", title="Avg Net Exposure (Details)")
+                avg_net_exposures.plot(
+                    ax=axis, kind="bar", title="Avg Net Exposure (Details)"
+                )
                 axis.set_ylabel("Percentage of capital")
 
             if performance.total_holdings is not None:
                 avg_total_holdings = performance.total_holdings.mean()
                 axis = fig.add_subplot(rows, 2, next_pos)
                 next_pos += 1
-                avg_total_holdings.plot(ax=axis, kind="bar", title="Avg Daily Holdings (Details)")
+                avg_total_holdings.plot(
+                    ax=axis, kind="bar", title="Avg Daily Holdings (Details)"
+                )
                 axis.set_ylabel("Number of holdings")
 
             if performance.turnover is not None:
@@ -682,7 +749,9 @@ class Tearsheet(BaseTearsheet):
                 axis = fig.add_subplot(rows, 2, next_pos)
                 next_pos += 1
                 self._y_format_as_percentage(axis)
-                avg_daily_turnover.plot(ax=axis, kind="bar", title="Avg Daily Turnover (Details)")
+                avg_daily_turnover.plot(
+                    ax=axis, kind="bar", title="Avg Daily Turnover (Details)"
+                )
                 axis.set_ylabel("Percentage of capital")
 
             if performance.abs_exposures is not None:
@@ -690,23 +759,13 @@ class Tearsheet(BaseTearsheet):
                 axis = fig.add_subplot(rows, 2, next_pos)
                 next_pos += 1
                 self._y_format_as_percentage(axis)
-                norm_cagrs.plot(ax=axis, kind="bar", title="Normalized CAGR (CAGR/Absolute Exposure) (Details)")
+                norm_cagrs.plot(
+                    ax=axis,
+                    kind="bar",
+                    title="Normalized CAGR (CAGR/Absolute Exposure) (Details)",
+                )
                 axis.set_ylabel("Normalized CAGR")
 
-            if performance.total_holdings is not None:
-                axis = fig.add_subplot(rows, 2, next_pos)
-                next_pos += 1
-                holding_periods_pos = performance.average_holding_periods_pos
-                holding_periods_pos.plot(ax=axis, kind="bar", title="Average Holding Period")
-                axis.set_ylabel("Bars ({})".format(performance.bar_size.time_string()))
-
-                holding_periods_null = performance.average_holding_periods_null
-                if holding_periods_null is not None:
-                    axis = fig.add_subplot(rows, 2, next_pos)
-                    next_pos += 1
-                    holding_periods_null.plot(ax=axis, kind="bar", title="Average Holding Period in Cash")
-                    axis.set_ylabel("Bars ({})".format(performance.bar_size.time_string()))
-
         fig.tight_layout()
 
     def create_returns_by_year_tearsheet(self, performance, agg_performance=None):
@@ -751,14 +810,13 @@ class Tearsheet(BaseTearsheet):
             rows=2 if show_details else 1,
             row=1,
             fig=fig,
-            extra_label="(Aggregate)" if show_details else "")
+            extra_label="(Aggregate)" if show_details else "",
+        )
 
         if show_details:
-            self._create_returns_by_year_plots(performance, rows=2, row=2, fig=fig, extra_label="(Details)")
-
-        fig = plt.figure("Returns by Position Type", figsize=(width, height))
-
-        self._create_returns_by_position_type(performance, fig=fig)
+            self._create_returns_by_year_plots(
+                performance, rows=2, row=2, fig=fig, extra_label="(Details)"
+            )
 
     def _create_returns_by_year_plots(self, performance, rows, row, fig, extra_label):
 
@@ -772,10 +830,15 @@ class Tearsheet(BaseTearsheet):
             color_palette = sns.color_palette()[0:1]
 
         grouped_returns = performance.returns.groupby(performance.returns.index.year)
-        cagrs_by_year = grouped_returns.apply(lambda x: get_cagr(
-            get_cum_returns(x, compound=performance.compound),
-            compound=performance.compound))
-        sharpes_by_year = grouped_returns.apply(get_sharpe, riskfree=performance.riskfree)
+        cagrs_by_year = grouped_returns.apply(
+            lambda x: get_cagr(
+                get_cum_returns(x, compound=performance.compound),
+                compound=performance.compound,
+            )
+        )
+        sharpes_by_year = grouped_returns.apply(
+            get_sharpe, riskfree=performance.riskfree
+        )
 
         # 2 cols per row, minus 1, gives the start position
         start_at = 2 * row - 1
@@ -783,7 +846,9 @@ class Tearsheet(BaseTearsheet):
             axis = fig.add_subplot(rows, 2, start_at)
             axis.set_ylabel("CAGR")
             self._y_format_as_percentage(axis)
-            plot = cagrs_by_year.plot(ax=axis, kind="bar", title="CAGR by Year {0}".format(extra_label))
+            plot = cagrs_by_year.plot(
+                ax=axis, kind="bar", title="CAGR by Year {0}".format(extra_label)
+            )
             axis.set_xlabel("")
             if isinstance(cagrs_by_year, pd.DataFrame):
                 # Remove legend, rely on legend from Sharpe plot
@@ -792,78 +857,18 @@ class Tearsheet(BaseTearsheet):
             axis = fig.add_subplot(rows, 2, start_at + 1)
             axis.set_ylabel("Sharpe ratio")
             self._y_format_at_least_two_decimal_places(axis)
-            plot = sharpes_by_year.plot(ax=axis, kind="bar", title="Sharpe by Year {0}".format(extra_label))
+            plot = sharpes_by_year.plot(
+                ax=axis, kind="bar", title="Sharpe by Year {0}".format(extra_label)
+            )
             axis.set_xlabel("")
             if isinstance(sharpes_by_year, pd.DataFrame):
                 self._clear_legend(plot)
 
         fig.tight_layout()
 
-    def _create_returns_by_position_type(self, performance, fig, extra_label=""):
-
-        color_palette = sns.color_palette()
-
-        if isinstance(performance.returns, pd.DataFrame):
-            num_series = len(performance.cum_returns.columns)
-            if num_series > 6:
-                color_palette = sns.color_palette("hls", num_series)
-        else:
-            color_palette = sns.color_palette()[0:1]
-
-        grouped_returns_longs = performance.returns_longs.groupby(performance.returns_longs.index.year)
-        cagrs_by_year_longs = grouped_returns_longs.apply(lambda x: get_cagr(
-            get_cum_returns(x, compound=performance.compound),
-            compound=performance.compound))
-        sharpes_by_year_longs = grouped_returns_longs.apply(get_sharpe, riskfree=performance.riskfree)
-
-        grouped_returns_shorts = performance.returns_shorts.groupby(performance.returns_shorts.index.year)
-        cagrs_by_year_shorts = grouped_returns_shorts.apply(lambda x: get_cagr(
-            get_cum_returns(x, compound=performance.compound),
-            compound=performance.compound))
-        sharpes_by_year_shorts = grouped_returns_shorts.apply(get_sharpe, riskfree=performance.riskfree)
-
-        with sns.color_palette(color_palette):
-            axis = fig.add_subplot(2, 2, 1)
-            axis.set_ylabel("CAGR")
-            self._y_format_as_percentage(axis)
-            plot = cagrs_by_year_longs.plot(ax=axis, kind="bar",
-                                            title="Longs - CAGR by Year {0}".format(extra_label))
-            axis.set_xlabel("")
-            if isinstance(cagrs_by_year_longs, pd.DataFrame):
-                # Remove legend, rely on legend from Sharpe plot
-                plot.legend_.remove()
-
-            axis = fig.add_subplot(2, 2, 2)
-            axis.set_ylabel("Sharpe ratio")
-            self._y_format_at_least_two_decimal_places(axis)
-            plot = sharpes_by_year_longs.plot(ax=axis, kind="bar",
-                                              title="Longs - Sharpe by Year {0}".format(extra_label))
-            axis.set_xlabel("")
-            if isinstance(sharpes_by_year_longs, pd.DataFrame):
-                self._clear_legend(plot)
-
-            axis = fig.add_subplot(2, 2, 3)
-            axis.set_ylabel("CAGR")
-            self._y_format_as_percentage(axis)
-            plot = cagrs_by_year_shorts.plot(ax=axis, kind="bar",
-                                             title="Shorts - CAGR by Year {0}".format(extra_label))
-            axis.set_xlabel("")
-            if isinstance(cagrs_by_year_shorts, pd.DataFrame):
-                # Remove legend, rely on legend from Sharpe plot
-                plot.legend_.remove()
-
-            axis = fig.add_subplot(2, 2, 4)
-            axis.set_ylabel("Sharpe ratio")
-            self._y_format_at_least_two_decimal_places(axis)
-            plot = sharpes_by_year_shorts.plot(ax=axis, kind="bar",
-                                               title="Shorts - Sharpe by Year {0}".format(extra_label))
-            axis.set_xlabel("")
-            if isinstance(sharpes_by_year_shorts, pd.DataFrame):
-                self._clear_legend(plot)
-
-        fig.tight_layout()
-
-    def create_montecarlo_tearsheet(self, performance, cycles=5, aggregate_before_shuffle=True):
+    def create_montecarlo_tearsheet(
+        self, performance, cycles=5, aggregate_before_shuffle=True
+    ):
         """
         Run a Montecarlo simulation by shuffling the DataFrame of returns a specified
         number of times and plotting the shuffled returns against the original returns.
@@ -904,7 +909,9 @@ class Tearsheet(BaseTearsheet):
 
         for i in range(cycles):
             if aggregate_before_shuffle:
-                sim_returns = pd.Series(np.random.permutation(returns), index=returns.index)
+                sim_returns = pd.Series(
+                    np.random.permutation(returns), index=returns.index
+                )
             else:
                 sim_returns = returns.apply(np.random.permutation).sum(axis=1)
             all_simulations.append(sim_returns)
@@ -926,11 +933,17 @@ class Tearsheet(BaseTearsheet):
         self._y_format_at_least_two_decimal_places(axis)
         axis.set_ylabel("Cumulative return")
         with_baseline(cum_sim_returns).plot(
-            ax=axis, title="Montecarlo Cumulative Returns ({0} cycles)".format(cycles), legend=False)
+            ax=axis,
+            title="Montecarlo Cumulative Returns ({0} cycles)".format(cycles),
+            legend=False,
+        )
         with_baseline(cum_returns).plot(ax=axis, linewidth=4, color="black")
         axis = fig.add_subplot(212)
         self._y_format_as_percentage(axis)
         axis.set_ylabel("Drawdown")
         get_drawdowns(cum_sim_returns).plot(
-            ax=axis, title="Montecarlo Drawdowns ({0} cycles)".format(cycles), legend=False)
+            ax=axis,
+            title="Montecarlo Drawdowns ({0} cycles)".format(cycles),
+            legend=False,
+        )
         get_drawdowns(cum_returns).plot(ax=axis, linewidth=4, color="black")
