@@ -1,4 +1,5 @@
-# Copyright 2019 QuantRocket LLC - All Rights Reserved
+# -*- coding: utf-8 -*-
+# Copyright 2017-2022 QuantRocket LLC - All Rights Reserved
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -12,18 +13,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from enum import IntEnum
-from itertools import groupby
-from collections import defaultdict
-
-import arrow
-
 import seaborn as sns
-
 import pandas as pd
-
 import numpy as np
-
 from .exceptions import MoonchartError
 
 
@@ -202,7 +194,9 @@ def get_rolling_sharpe(returns, window, riskfree=0):
     returns = _pad_returns(returns)
     rolling_returns = returns.rolling(window, min_periods=window)
     try:
-        return rolling_returns.apply(_get_sharpe, raw=True, kwargs=dict(riskfree=riskfree))
+        return rolling_returns.apply(
+            _get_sharpe, raw=True, kwargs=dict(riskfree=riskfree)
+        )
     except TypeError as e:
         # handle pandas<0.23
         if "apply() got an unexpected keyword argument 'raw'" in repr(e):
@@ -273,7 +267,7 @@ def get_cagr(cum_returns, compound=True):
     # value is always 1.
     beginning_value = 1
     if compound:
-        cagr = (ending_value / beginning_value)**(1 / years) - 1
+        cagr = (ending_value / beginning_value) ** (1 / years) - 1
     else:
         # Compound annual growth rate doesn't apply to arithmetic
         # returns, so just divide the cum_returns by the number of years
@@ -398,22 +392,22 @@ def intraday_to_daily(results, how=None):
 
     # how to aggregate by field
     field_hows = {
-        'AbsExposure': 'max',
-        'AbsWeight': 'max',
-        'Benchmark': 'last',
-        'Commission': 'sum',
-        'CommissionAmount': 'sum',
-        'NetExposure': 'extreme',
-        'NetLiquidation': 'mean',
-        'Pnl': 'sum',
-        'PositionQuantity': 'extreme',
-        'PositionValue': 'extreme',
-        'Price': 'last',
-        'Return': 'sum',
-        'Slippage': 'sum',
-        'TotalHoldings': 'max',
-        'Turnover': 'sum',
-        'Weight': 'extreme',
+        "AbsExposure": "max",
+        "AbsWeight": "max",
+        "Benchmark": "last",
+        "Commission": "sum",
+        "CommissionAmount": "sum",
+        "NetExposure": "extreme",
+        "NetLiquidation": "mean",
+        "Pnl": "sum",
+        "PositionQuantity": "extreme",
+        "PositionValue": "extreme",
+        "Price": "last",
+        "Return": "sum",
+        "Slippage": "sum",
+        "TotalHoldings": "max",
+        "Turnover": "sum",
+        "Weight": "extreme",
     }
 
     if how:
@@ -429,104 +423,15 @@ def intraday_to_daily(results, how=None):
         grouped = field_results.groupby(field_results.index.get_level_values("Date"))
 
         if field_how == "extreme":
-            mins = field_results.groupby(field_results.index.get_level_values("Date")).min()
-            maxes = field_results.groupby(field_results.index.get_level_values("Date")).max()
+            mins = field_results.groupby(
+                field_results.index.get_level_values("Date")
+            ).min()
+            maxes = field_results.groupby(
+                field_results.index.get_level_values("Date")
+            ).max()
             daily_results[field] = mins.where(mins.abs() > maxes.abs(), maxes)
         else:
             daily_results[field] = getattr(grouped, field_how)()
 
     daily_results = pd.concat(daily_results, names=["Field", "Date"])
     return daily_results
-
-
-def get_average_holding_periods(total_holdings, comp_func=lambda x: x > 0):
-    holdings_data = defaultdict(list)
-    for asset in total_holdings:
-        ind = prev = 0
-        for k, v in groupby(total_holdings[asset], key=comp_func):
-            ind += sum(1 for _ in v)
-            if k and prev + 1 != ind:
-                holdings_data[asset].append(ind - prev - 1)
-            prev = ind
-
-    df_data = {}
-    for asset, holding_periods in holdings_data.items():
-        df_data[asset] = [np.min(holding_periods), np.max(holding_periods), np.average(holding_periods)]
-
-    holdings_data = pd.DataFrame.from_dict(df_data, orient="index")
-    if holdings_data.empty:
-        return None
-    holdings_data.columns = ["Min", "Max", "Avg"]
-
-    return holdings_data
-
-
-class HistoryFrequency(IntEnum):
-    SECOND_1 = 1
-    SECOND_5 = 5
-    SECOND_10 = 10
-    SECOND_15 = 15
-    SECOND_30 = 30
-    MINUTE_1 = 60
-    MINUTE_2 = 120
-    MINUTE_3 = 180
-    MINUTE_5 = 300
-    MINUTE_10 = 600
-    MINUTE_15 = 900
-    MINUTE_20 = 1200
-    MINUTE_30 = 1800
-    HOUR_1 = 3600
-    HOUR_2 = 7200
-    HOUR_3 = 10800
-    HOUR_4 = 14400
-    HOUR_8 = 28800
-    DAY_1 = 86400
-    WEEK_1 = 604800
-    MONTH_1 = 2629800
-
-    def __init__(self, seconds: int):
-        self.seconds = seconds
-
-    def time_string(self):
-        second_time_string_map = {1: "1s", 5: "5s", 10: "10s", 15: "15s", 30: "30s", 60: "1Min", 120: "2Min",
-                                  180: "3Min", 300: "5Min", 600: "10Min", 900: "15Min", 1200: "20Min", 1800: "30Min",
-                                  3600: "1H", 7200: "2H", 10800: "3H", 14400: "4H", 28800: "8H", 86400: "1D",
-                                  604800: "1W", 2629800: "1M"}
-        return second_time_string_map[self.seconds]
-
-
-def get_bar_size(df):
-    filled = df.bfill().ffill()
-
-    if isinstance(filled.index, pd.MultiIndex):
-        dates = filled.index.levels[0]
-        if "Time" in filled.index.names:
-            times = filled.index.levels[1]
-            datetime_start_one = arrow.get("{} {}".format(dates[0], times[0]), "YYYY-MM-DD HH:mm:ss")
-            datetime_stop_one = arrow.get("{} {}".format(dates[0], times[1]), "YYYY-MM-DD HH:mm:ss")
-            datetime_start_two = arrow.get("{} {}".format(dates[1], times[0]), "YYYY-MM-DD HH:mm:ss")
-            datetime_stop_two = arrow.get("{} {}".format(dates[1], times[1]), "YYYY-MM-DD HH:mm:ss")
-            combined_one = datetime_stop_one - datetime_start_one
-            combined_two = datetime_stop_two - datetime_start_two
-        else:
-            datetime_start_one = arrow.get(dates[0], "YYYY-MM-DD")
-            datetime_stop_one = arrow.get(dates[1], "YYYY-MM-DD")
-            datetime_start_two = arrow.get(dates[1], "YYYY-MM-DD")
-            datetime_stop_two = arrow.get(dates[2], "YYYY-MM-DD")
-            combined_one = datetime_stop_one - datetime_start_one
-            combined_two = datetime_stop_two - datetime_start_two
-    else:
-        dates = filled.index
-        datetime_start_one = arrow.get(dates[0])
-        datetime_stop_one = arrow.get(dates[1])
-        datetime_start_two = arrow.get(dates[1])
-        datetime_stop_two = arrow.get(dates[2])
-        combined_one = datetime_stop_one - datetime_start_one
-        combined_two = datetime_stop_two - datetime_start_two
-
-    try:
-        default_frequency = HistoryFrequency(combined_one.total_seconds())
-    except:
-        default_frequency = HistoryFrequency(combined_two.total_seconds())
-
-    return default_frequency
